/*
 * This file is a component of thundr, a software library from 3wks.
 * Read more: http://www.3wks.com.au/thundr
 * Copyright (C) 2013 3wks, <thundr@3wks.com.au>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.threewks.thundr.googleapis.cloudstorage;

import java.io.InputStream;

/**
 * Service for interacting with Google Cloud Storage.
 * 
 * https://developers.google.com/storage/
 * https://cloud.google.com/products/cloud-storage
 */
public interface GoogleCloudStorageService {

	/**
	 * Get a bucket.
	 * 
	 * @param bucketRequest the details of the bucket being requested.
	 * @return the bucket.
	 */
	public Bucket getBucket(BucketRequest bucketRequest);

	/**
	 * Move an object from one bucket to another.
	 * 
	 * @param sourceBucket the source bucket.
	 * @param targetBucket the target bucket.
	 * @param object the object to move.
	 */
	public void moveObject(String sourceBucket, String targetBucket, String object);

	/**
	 * Get an object.
	 * 
	 * @param bucket the name of the bucket.
	 * @param object the name of the object.
	 * @return an {@link InputStream} containing the object data.
	 */
	public InputStream getObject(String bucket, String object);

}